@@ -18,7 +18,7 @@ use warnings qw'all' ;
   
   #use Data::Dumper ; print Dumper( $R ) ; exit ;
 
-  ok( $R->startR ) ;
+  ok( $R->startRShared ) ;
   
   ok( $R->Rbin ) ;
   
